from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.regeneration_fn_name import RegenerationFnName
from ..types import UNSET, Unset

T = TypeVar("T", bound="SegmentConfiguration")


@attr.s(auto_attribs=True)
class SegmentConfiguration:
    """Class for configuring blog segment generation.

    Attributes:
        prompt_template_name (Union[Unset, str]):
        prompt_template_string (Union[Unset, str]):
        system_message_name (Union[Unset, str]):
        system_message_string (Union[Unset, str]):
        completion_max_tokens (Union[Unset, int]):
        temperature (Union[Unset, float]):
        regeneration_fn (Union[Unset, RegenerationFnName]): Enumerable for regeneration functions.
        regeneration_tries (Union[Unset, int]):
        regeneration_threshold (Union[Unset, float]):
    """

    prompt_template_name: Union[Unset, str] = UNSET
    prompt_template_string: Union[Unset, str] = UNSET
    system_message_name: Union[Unset, str] = UNSET
    system_message_string: Union[Unset, str] = UNSET
    completion_max_tokens: Union[Unset, int] = UNSET
    temperature: Union[Unset, float] = UNSET
    regeneration_fn: Union[Unset, RegenerationFnName] = UNSET
    regeneration_tries: Union[Unset, int] = UNSET
    regeneration_threshold: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        prompt_template_name = self.prompt_template_name
        prompt_template_string = self.prompt_template_string
        system_message_name = self.system_message_name
        system_message_string = self.system_message_string
        completion_max_tokens = self.completion_max_tokens
        temperature = self.temperature
        regeneration_fn: Union[Unset, str] = UNSET
        if not isinstance(self.regeneration_fn, Unset):
            regeneration_fn = self.regeneration_fn.value

        regeneration_tries = self.regeneration_tries
        regeneration_threshold = self.regeneration_threshold

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if prompt_template_name is not UNSET:
            field_dict["prompt_template_name"] = prompt_template_name
        if prompt_template_string is not UNSET:
            field_dict["prompt_template_string"] = prompt_template_string
        if system_message_name is not UNSET:
            field_dict["system_message_name"] = system_message_name
        if system_message_string is not UNSET:
            field_dict["system_message_string"] = system_message_string
        if completion_max_tokens is not UNSET:
            field_dict["completion_max_tokens"] = completion_max_tokens
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if regeneration_fn is not UNSET:
            field_dict["regeneration_fn"] = regeneration_fn
        if regeneration_tries is not UNSET:
            field_dict["regeneration_tries"] = regeneration_tries
        if regeneration_threshold is not UNSET:
            field_dict["regeneration_threshold"] = regeneration_threshold

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        prompt_template_name = d.pop("prompt_template_name", UNSET)

        prompt_template_string = d.pop("prompt_template_string", UNSET)

        system_message_name = d.pop("system_message_name", UNSET)

        system_message_string = d.pop("system_message_string", UNSET)

        completion_max_tokens = d.pop("completion_max_tokens", UNSET)

        temperature = d.pop("temperature", UNSET)

        _regeneration_fn = d.pop("regeneration_fn", UNSET)
        regeneration_fn: Union[Unset, RegenerationFnName]
        if isinstance(_regeneration_fn, Unset):
            regeneration_fn = UNSET
        else:
            regeneration_fn = RegenerationFnName(_regeneration_fn)

        regeneration_tries = d.pop("regeneration_tries", UNSET)

        regeneration_threshold = d.pop("regeneration_threshold", UNSET)

        segment_configuration = cls(
            prompt_template_name=prompt_template_name,
            prompt_template_string=prompt_template_string,
            system_message_name=system_message_name,
            system_message_string=system_message_string,
            completion_max_tokens=completion_max_tokens,
            temperature=temperature,
            regeneration_fn=regeneration_fn,
            regeneration_tries=regeneration_tries,
            regeneration_threshold=regeneration_threshold,
        )

        segment_configuration.additional_properties = d
        return segment_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UsageLimits")


@attr.s(auto_attribs=True)
class UsageLimits:
    """Usage limits response model.

    Attributes:
        is_unlimited (bool):
        friendly_message (str):
        period (Union[Unset, str]):
        limit (Union[Unset, float]):
        current (Union[Unset, float]):
    """

    is_unlimited: bool
    friendly_message: str
    period: Union[Unset, str] = UNSET
    limit: Union[Unset, float] = UNSET
    current: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        is_unlimited = self.is_unlimited
        friendly_message = self.friendly_message
        period = self.period
        limit = self.limit
        current = self.current

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "is_unlimited": is_unlimited,
                "friendly_message": friendly_message,
            }
        )
        if period is not UNSET:
            field_dict["period"] = period
        if limit is not UNSET:
            field_dict["limit"] = limit
        if current is not UNSET:
            field_dict["current"] = current

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        is_unlimited = d.pop("is_unlimited")

        friendly_message = d.pop("friendly_message")

        period = d.pop("period", UNSET)

        limit = d.pop("limit", UNSET)

        current = d.pop("current", UNSET)

        usage_limits = cls(
            is_unlimited=is_unlimited,
            friendly_message=friendly_message,
            period=period,
            limit=limit,
            current=current,
        )

        usage_limits.additional_properties = d
        return usage_limits

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RegenerationFnName(str, Enum):
    LENGTH_UNDER_200 = "length_under_200"
    SVR_REGENERATION_SCORE = "svr_regeneration_score"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class BlogSegmentType(str, Enum):
    BODY = "body"
    CODE = "code"
    HEADING = "heading"
    IMAGE = "image"
    QUESTION = "question"
    USER_BODY = "user_body"
    USER_CODE = "user_code"
    USER_HEADING = "user_heading"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.contenda_body_segment_save_request import ContendaBodySegmentSaveRequest
from ...models.contenda_code_segment_save_request import ContendaCodeSegmentSaveRequest
from ...models.contenda_heading_segment_save_request import ContendaHeadingSegmentSaveRequest
from ...models.contenda_image_segment_save_request import ContendaImageSegmentSaveRequest
from ...models.http_validation_error import HTTPValidationError
from ...models.save_blog_result_document_api_v2_content_blog_blog_id_put_response_save_blog_result_document_api_v2_content_blog_blog_id_put import (
    SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
)
from ...models.user_body_segment_save_request import UserBodySegmentSaveRequest
from ...models.user_code_segment_save_request import UserCodeSegmentSaveRequest
from ...models.user_heading_segment_save_request import UserHeadingSegmentSaveRequest
from ...types import UNSET, Response


def _get_kwargs(
    blog_id: str,
    *,
    client: Client,
    json_body: List[
        Union[
            "ContendaBodySegmentSaveRequest",
            "ContendaCodeSegmentSaveRequest",
            "ContendaHeadingSegmentSaveRequest",
            "ContendaImageSegmentSaveRequest",
            "UserBodySegmentSaveRequest",
            "UserCodeSegmentSaveRequest",
            "UserHeadingSegmentSaveRequest",
        ]
    ],
    token: str,
) -> Dict[str, Any]:
    url = "{}/api/v2/content/blog/{blog_id}".format(client.base_url, blog_id=blog_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["token"] = token

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = []
    for json_body_item_data in json_body:
        json_body_item: Dict[str, Any]

        if isinstance(json_body_item_data, ContendaBodySegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        elif isinstance(json_body_item_data, ContendaHeadingSegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        elif isinstance(json_body_item_data, ContendaCodeSegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        elif isinstance(json_body_item_data, ContendaImageSegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        elif isinstance(json_body_item_data, UserBodySegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        elif isinstance(json_body_item_data, UserHeadingSegmentSaveRequest):
            json_body_item = json_body_item_data.to_dict()

        else:
            json_body_item = json_body_item_data.to_dict()

        json_json_body.append(json_body_item)

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut.from_dict(
            response.json()
        )

        return response_200
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    blog_id: str,
    *,
    client: Client,
    json_body: List[
        Union[
            "ContendaBodySegmentSaveRequest",
            "ContendaCodeSegmentSaveRequest",
            "ContendaHeadingSegmentSaveRequest",
            "ContendaImageSegmentSaveRequest",
            "UserBodySegmentSaveRequest",
            "UserCodeSegmentSaveRequest",
            "UserHeadingSegmentSaveRequest",
        ]
    ],
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    """Save edits to a result blog.

     Save the given list of blog segment objects from the client request body as the resulting blog.

    Segment types `body`, `heading`, `image`, and `code` are segments created by Contenda.
    Look at the request body schema examples to see the required body fields given each `segment_type`.

    Edited or Keep as is?
    - include segment object with the updated field or with its original value!

    Addition
    - add a new segment object with a uuid generated `id` to the list of blog segemnt objects in your
    request
    - these must be of segment type `user_heading`, `user_body`, `user_code` as they are your added
    segments

    Deletions and Reordering
    - the blog is saved as given in the request, so any segment removed or reordered will do the trick!

    Args:
        blog_id (str): ID of the blog in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`
        token (str):
        json_body (List[Union['ContendaBodySegmentSaveRequest', 'ContendaCodeSegmentSaveRequest',
            'ContendaHeadingSegmentSaveRequest', 'ContendaImageSegmentSaveRequest',
            'UserBodySegmentSaveRequest', 'UserCodeSegmentSaveRequest',
            'UserHeadingSegmentSaveRequest']]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut]]
    """

    kwargs = _get_kwargs(
        blog_id=blog_id,
        client=client,
        json_body=json_body,
        token=token,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    blog_id: str,
    *,
    client: Client,
    json_body: List[
        Union[
            "ContendaBodySegmentSaveRequest",
            "ContendaCodeSegmentSaveRequest",
            "ContendaHeadingSegmentSaveRequest",
            "ContendaImageSegmentSaveRequest",
            "UserBodySegmentSaveRequest",
            "UserCodeSegmentSaveRequest",
            "UserHeadingSegmentSaveRequest",
        ]
    ],
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    """Save edits to a result blog.

     Save the given list of blog segment objects from the client request body as the resulting blog.

    Segment types `body`, `heading`, `image`, and `code` are segments created by Contenda.
    Look at the request body schema examples to see the required body fields given each `segment_type`.

    Edited or Keep as is?
    - include segment object with the updated field or with its original value!

    Addition
    - add a new segment object with a uuid generated `id` to the list of blog segemnt objects in your
    request
    - these must be of segment type `user_heading`, `user_body`, `user_code` as they are your added
    segments

    Deletions and Reordering
    - the blog is saved as given in the request, so any segment removed or reordered will do the trick!

    Args:
        blog_id (str): ID of the blog in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`
        token (str):
        json_body (List[Union['ContendaBodySegmentSaveRequest', 'ContendaCodeSegmentSaveRequest',
            'ContendaHeadingSegmentSaveRequest', 'ContendaImageSegmentSaveRequest',
            'UserBodySegmentSaveRequest', 'UserCodeSegmentSaveRequest',
            'UserHeadingSegmentSaveRequest']]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut]
    """

    return sync_detailed(
        blog_id=blog_id,
        client=client,
        json_body=json_body,
        token=token,
    ).parsed


async def asyncio_detailed(
    blog_id: str,
    *,
    client: Client,
    json_body: List[
        Union[
            "ContendaBodySegmentSaveRequest",
            "ContendaCodeSegmentSaveRequest",
            "ContendaHeadingSegmentSaveRequest",
            "ContendaImageSegmentSaveRequest",
            "UserBodySegmentSaveRequest",
            "UserCodeSegmentSaveRequest",
            "UserHeadingSegmentSaveRequest",
        ]
    ],
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    """Save edits to a result blog.

     Save the given list of blog segment objects from the client request body as the resulting blog.

    Segment types `body`, `heading`, `image`, and `code` are segments created by Contenda.
    Look at the request body schema examples to see the required body fields given each `segment_type`.

    Edited or Keep as is?
    - include segment object with the updated field or with its original value!

    Addition
    - add a new segment object with a uuid generated `id` to the list of blog segemnt objects in your
    request
    - these must be of segment type `user_heading`, `user_body`, `user_code` as they are your added
    segments

    Deletions and Reordering
    - the blog is saved as given in the request, so any segment removed or reordered will do the trick!

    Args:
        blog_id (str): ID of the blog in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`
        token (str):
        json_body (List[Union['ContendaBodySegmentSaveRequest', 'ContendaCodeSegmentSaveRequest',
            'ContendaHeadingSegmentSaveRequest', 'ContendaImageSegmentSaveRequest',
            'UserBodySegmentSaveRequest', 'UserCodeSegmentSaveRequest',
            'UserHeadingSegmentSaveRequest']]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut]]
    """

    kwargs = _get_kwargs(
        blog_id=blog_id,
        client=client,
        json_body=json_body,
        token=token,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    blog_id: str,
    *,
    client: Client,
    json_body: List[
        Union[
            "ContendaBodySegmentSaveRequest",
            "ContendaCodeSegmentSaveRequest",
            "ContendaHeadingSegmentSaveRequest",
            "ContendaImageSegmentSaveRequest",
            "UserBodySegmentSaveRequest",
            "UserCodeSegmentSaveRequest",
            "UserHeadingSegmentSaveRequest",
        ]
    ],
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
    ]
]:
    """Save edits to a result blog.

     Save the given list of blog segment objects from the client request body as the resulting blog.

    Segment types `body`, `heading`, `image`, and `code` are segments created by Contenda.
    Look at the request body schema examples to see the required body fields given each `segment_type`.

    Edited or Keep as is?
    - include segment object with the updated field or with its original value!

    Addition
    - add a new segment object with a uuid generated `id` to the list of blog segemnt objects in your
    request
    - these must be of segment type `user_heading`, `user_body`, `user_code` as they are your added
    segments

    Deletions and Reordering
    - the blog is saved as given in the request, so any segment removed or reordered will do the trick!

    Args:
        blog_id (str): ID of the blog in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`
        token (str):
        json_body (List[Union['ContendaBodySegmentSaveRequest', 'ContendaCodeSegmentSaveRequest',
            'ContendaHeadingSegmentSaveRequest', 'ContendaImageSegmentSaveRequest',
            'UserBodySegmentSaveRequest', 'UserCodeSegmentSaveRequest',
            'UserHeadingSegmentSaveRequest']]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut]
    """

    return (
        await asyncio_detailed(
            blog_id=blog_id,
            client=client,
            json_body=json_body,
            token=token,
        )
    ).parsed



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.http_validation_error import HTTPValidationError
from ...models.save_segment_revision_feedback_api_v2_content_blog_segment_revision_feedback_revision_id_put_response_save_segment_revision_feedback_api_v2_content_blog_segment_revision_feedback_revision_id_put import (
    SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
)
from ...models.segment_revision_feedback_request_model import SegmentRevisionFeedbackRequestModel
from ...types import UNSET, Response


def _get_kwargs(
    revision_id: str,
    *,
    client: Client,
    json_body: SegmentRevisionFeedbackRequestModel,
    token: str,
) -> Dict[str, Any]:
    url = "{}/api/v2/content/blog/segment/revision/feedback/{revision_id}".format(
        client.base_url, revision_id=revision_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["token"] = token

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut.from_dict(
            response.json()
        )

        return response_200
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    revision_id: str,
    *,
    client: Client,
    json_body: SegmentRevisionFeedbackRequestModel,
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    """Save feedback for a regenerated segment.

     Save feedback for why a segment was regenerated.

    The labels to use for feedback is given by the endpoint `GET
    /api/v2/content/blog/segment/revision/feedback-options`

    Args:
        revision_id (str): ID of the segment revision in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`. This ID can be found after regenerating a segment.
        token (str):
        json_body (SegmentRevisionFeedbackRequestModel): Response model for the body input of
            saving segment revisions after regeneration.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut]]
    """

    kwargs = _get_kwargs(
        revision_id=revision_id,
        client=client,
        json_body=json_body,
        token=token,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    revision_id: str,
    *,
    client: Client,
    json_body: SegmentRevisionFeedbackRequestModel,
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    """Save feedback for a regenerated segment.

     Save feedback for why a segment was regenerated.

    The labels to use for feedback is given by the endpoint `GET
    /api/v2/content/blog/segment/revision/feedback-options`

    Args:
        revision_id (str): ID of the segment revision in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`. This ID can be found after regenerating a segment.
        token (str):
        json_body (SegmentRevisionFeedbackRequestModel): Response model for the body input of
            saving segment revisions after regeneration.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut]
    """

    return sync_detailed(
        revision_id=revision_id,
        client=client,
        json_body=json_body,
        token=token,
    ).parsed


async def asyncio_detailed(
    revision_id: str,
    *,
    client: Client,
    json_body: SegmentRevisionFeedbackRequestModel,
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    """Save feedback for a regenerated segment.

     Save feedback for why a segment was regenerated.

    The labels to use for feedback is given by the endpoint `GET
    /api/v2/content/blog/segment/revision/feedback-options`

    Args:
        revision_id (str): ID of the segment revision in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`. This ID can be found after regenerating a segment.
        token (str):
        json_body (SegmentRevisionFeedbackRequestModel): Response model for the body input of
            saving segment revisions after regeneration.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut]]
    """

    kwargs = _get_kwargs(
        revision_id=revision_id,
        client=client,
        json_body=json_body,
        token=token,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    revision_id: str,
    *,
    client: Client,
    json_body: SegmentRevisionFeedbackRequestModel,
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
    ]
]:
    """Save feedback for a regenerated segment.

     Save feedback for why a segment was regenerated.

    The labels to use for feedback is given by the endpoint `GET
    /api/v2/content/blog/segment/revision/feedback-options`

    Args:
        revision_id (str): ID of the segment revision in a `uuid4` format, e.g.
            `9ec1ff50-add4-402c-8656-c9147539cd4c`. This ID can be found after regenerating a segment.
        token (str):
        json_body (SegmentRevisionFeedbackRequestModel): Response model for the body input of
            saving segment revisions after regeneration.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut]
    """

    return (
        await asyncio_detailed(
            revision_id=revision_id,
            client=client,
            json_body=json_body,
            token=token,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.segment_configuration import SegmentConfiguration


T = TypeVar("T", bound="DocumentGenerationConfiguration")


@attr.s(auto_attribs=True)
class DocumentGenerationConfiguration:
    """Class for configuring blog document generation.

    Attributes:
        body_segment (Union[Unset, SegmentConfiguration]): Class for configuring blog segment generation.
        heading_segment (Union[Unset, SegmentConfiguration]): Class for configuring blog segment generation.
        question_segment (Union[Unset, SegmentConfiguration]): Class for configuring blog segment generation.
    """

    body_segment: Union[Unset, "SegmentConfiguration"] = UNSET
    heading_segment: Union[Unset, "SegmentConfiguration"] = UNSET
    question_segment: Union[Unset, "SegmentConfiguration"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        body_segment: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.body_segment, Unset):
            body_segment = self.body_segment.to_dict()

        heading_segment: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.heading_segment, Unset):
            heading_segment = self.heading_segment.to_dict()

        question_segment: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.question_segment, Unset):
            question_segment = self.question_segment.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if body_segment is not UNSET:
            field_dict["body_segment"] = body_segment
        if heading_segment is not UNSET:
            field_dict["heading_segment"] = heading_segment
        if question_segment is not UNSET:
            field_dict["question_segment"] = question_segment

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.segment_configuration import SegmentConfiguration

        d = src_dict.copy()
        _body_segment = d.pop("body_segment", UNSET)
        body_segment: Union[Unset, SegmentConfiguration]
        if isinstance(_body_segment, Unset):
            body_segment = UNSET
        else:
            body_segment = SegmentConfiguration.from_dict(_body_segment)

        _heading_segment = d.pop("heading_segment", UNSET)
        heading_segment: Union[Unset, SegmentConfiguration]
        if isinstance(_heading_segment, Unset):
            heading_segment = UNSET
        else:
            heading_segment = SegmentConfiguration.from_dict(_heading_segment)

        _question_segment = d.pop("question_segment", UNSET)
        question_segment: Union[Unset, SegmentConfiguration]
        if isinstance(_question_segment, Unset):
            question_segment = UNSET
        else:
            question_segment = SegmentConfiguration.from_dict(_question_segment)

        document_generation_configuration = cls(
            body_segment=body_segment,
            heading_segment=heading_segment,
            question_segment=question_segment,
        )

        document_generation_configuration.additional_properties = d
        return document_generation_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="BlogEntry")


@attr.s(auto_attribs=True)
class BlogEntry:
    """Blog entry response model.

    Attributes:
        id (str):
        title (str):
        owner_email (str):
        owner_name (str):
        created_at (datetime.datetime):
        labels (Union[Unset, List[str]]):
    """

    id: str
    title: str
    owner_email: str
    owner_name: str
    created_at: datetime.datetime
    labels: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        title = self.title
        owner_email = self.owner_email
        owner_name = self.owner_name
        created_at = self.created_at.isoformat()

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "title": title,
                "owner_email": owner_email,
                "owner_name": owner_name,
                "created_at": created_at,
            }
        )
        if labels is not UNSET:
            field_dict["labels"] = labels

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        title = d.pop("title")

        owner_email = d.pop("owner_email")

        owner_name = d.pop("owner_name")

        created_at = isoparse(d.pop("created_at"))

        labels = cast(List[str], d.pop("labels", UNSET))

        blog_entry = cls(
            id=id,
            title=title,
            owner_email=owner_email,
            owner_name=owner_name,
            created_at=created_at,
            labels=labels,
        )

        blog_entry.additional_properties = d
        return blog_entry

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="MediaItem")


@attr.s(auto_attribs=True)
class MediaItem:
    """Model for media items.

    Attributes:
        id (str):
        source_id (str):
        mime_type (str):
        owner_id (str):
        file_md5 (Union[Unset, str]):  Default: ''.
        length (Union[Unset, float]):
        title (Union[Unset, str]):  Default: ''.
        description (Union[Unset, str]):  Default: ''.
        created_at (Union[Unset, datetime.datetime]):
    """

    id: str
    source_id: str
    mime_type: str
    owner_id: str
    file_md5: Union[Unset, str] = ""
    length: Union[Unset, float] = 0.0
    title: Union[Unset, str] = ""
    description: Union[Unset, str] = ""
    created_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        source_id = self.source_id
        mime_type = self.mime_type
        owner_id = self.owner_id
        file_md5 = self.file_md5
        length = self.length
        title = self.title
        description = self.description
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "source_id": source_id,
                "mime_type": mime_type,
                "owner_id": owner_id,
            }
        )
        if file_md5 is not UNSET:
            field_dict["file_md5"] = file_md5
        if length is not UNSET:
            field_dict["length"] = length
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if created_at is not UNSET:
            field_dict["created_at"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        source_id = d.pop("source_id")

        mime_type = d.pop("mime_type")

        owner_id = d.pop("owner_id")

        file_md5 = d.pop("file_md5", UNSET)

        length = d.pop("length", UNSET)

        title = d.pop("title", UNSET)

        description = d.pop("description", UNSET)

        _created_at = d.pop("created_at", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        media_item = cls(
            id=id,
            source_id=source_id,
            mime_type=mime_type,
            owner_id=owner_id,
            file_md5=file_md5,
            length=length,
            title=title,
            description=description,
            created_at=created_at,
        )

        media_item.additional_properties = d
        return media_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="BlogImageResponseModel")


@attr.s(auto_attribs=True)
class BlogImageResponseModel:
    """Response model for an image derived from the blog's media.

    Attributes:
        timestamp (float):
        image_url (str):
        image_bucket (str):
        image_key (str):
    """

    timestamp: float
    image_url: str
    image_bucket: str
    image_key: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        timestamp = self.timestamp
        image_url = self.image_url
        image_bucket = self.image_bucket
        image_key = self.image_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "timestamp": timestamp,
                "image_url": image_url,
                "image_bucket": image_bucket,
                "image_key": image_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        timestamp = d.pop("timestamp")

        image_url = d.pop("image_url")

        image_bucket = d.pop("image_bucket")

        image_key = d.pop("image_key")

        blog_image_response_model = cls(
            timestamp=timestamp,
            image_url=image_url,
            image_bucket=image_bucket,
            image_key=image_key,
        )

        blog_image_response_model.additional_properties = d
        return blog_image_response_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .blog_entry import BlogEntry
from .blog_image_response_model import BlogImageResponseModel
from .blog_segment_type import BlogSegmentType
from .contenda_body_segment_save_request import ContendaBodySegmentSaveRequest
from .contenda_code_segment_save_request import ContendaCodeSegmentSaveRequest
from .contenda_heading_segment_save_request import ContendaHeadingSegmentSaveRequest
from .contenda_image_segment_save_request import ContendaImageSegmentSaveRequest
from .document_generation_configuration import DocumentGenerationConfiguration
from .generate_access_token import GenerateAccessToken
from .get_blog_result_document_api_v2_content_blog_blog_id_get_response_get_blog_result_document_api_v2_content_blog_blog_id_get import (
    GetBlogResultDocumentApiV2ContentBlogBlogIdGetResponseGetBlogResultDocumentApiV2ContentBlogBlogIdGet,
)
from .get_job_api_v2_jobs_status_job_id_get_response_get_job_api_v2_jobs_status_job_id_get import (
    GetJobApiV2JobsStatusJobIdGetResponseGetJobApiV2JobsStatusJobIdGet,
)
from .get_rss_feed_parsed_api_v2_blog_rss_feed_parsed_get_response_get_rss_feed_parsed_api_v2_blog_rss_feed_parsed_get import (
    GetRssFeedParsedApiV2BlogRssFeedParsedGetResponseGetRssFeedParsedApiV2BlogRssFeedParsedGet,
)
from .get_token_endpoint_api_v2_identity_token_post_response_get_token_endpoint_api_v2_identity_token_post import (
    GetTokenEndpointApiV2IdentityTokenPostResponseGetTokenEndpointApiV2IdentityTokenPost,
)
from .health_health_get_response_health_health_get import HealthHealthGetResponseHealthHealthGet
from .http_validation_error import HTTPValidationError
from .job_create_video_to_blog import JobCreateVideoToBlog
from .media_item import MediaItem
from .post_video_to_blog_job_api_v2_jobs_video_to_blog_post_response_post_video_to_blog_job_api_v2_jobs_video_to_blog_post import (
    PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
)
from .regeneration_fn_name import RegenerationFnName
from .regeneration_label import RegenerationLabel
from .save_blog_result_document_api_v2_content_blog_blog_id_put_response_save_blog_result_document_api_v2_content_blog_blog_id_put import (
    SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut,
)
from .save_segment_revision_feedback_api_v2_content_blog_segment_revision_feedback_revision_id_put_response_save_segment_revision_feedback_api_v2_content_blog_segment_revision_feedback_revision_id_put import (
    SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut,
)
from .segment_configuration import SegmentConfiguration
from .segment_revision_feedback_request_model import SegmentRevisionFeedbackRequestModel
from .transcript_line_response_model import TranscriptLineResponseModel
from .usage_limits import UsageLimits
from .user_body_segment_save_request import UserBodySegmentSaveRequest
from .user_code_segment_save_request import UserCodeSegmentSaveRequest
from .user_heading_segment_save_request import UserHeadingSegmentSaveRequest
from .validation_error import ValidationError
from .video_to_blog_type import VideoToBlogType

__all__ = (
    "BlogEntry",
    "BlogImageResponseModel",
    "BlogSegmentType",
    "ContendaBodySegmentSaveRequest",
    "ContendaCodeSegmentSaveRequest",
    "ContendaHeadingSegmentSaveRequest",
    "ContendaImageSegmentSaveRequest",
    "DocumentGenerationConfiguration",
    "GenerateAccessToken",
    "GetBlogResultDocumentApiV2ContentBlogBlogIdGetResponseGetBlogResultDocumentApiV2ContentBlogBlogIdGet",
    "GetJobApiV2JobsStatusJobIdGetResponseGetJobApiV2JobsStatusJobIdGet",
    "GetRssFeedParsedApiV2BlogRssFeedParsedGetResponseGetRssFeedParsedApiV2BlogRssFeedParsedGet",
    "GetTokenEndpointApiV2IdentityTokenPostResponseGetTokenEndpointApiV2IdentityTokenPost",
    "HealthHealthGetResponseHealthHealthGet",
    "HTTPValidationError",
    "JobCreateVideoToBlog",
    "MediaItem",
    "PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost",
    "RegenerationFnName",
    "RegenerationLabel",
    "SaveBlogResultDocumentApiV2ContentBlogBlogIdPutResponseSaveBlogResultDocumentApiV2ContentBlogBlogIdPut",
    "SaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPutResponseSaveSegmentRevisionFeedbackApiV2ContentBlogSegmentRevisionFeedbackRevisionIdPut",
    "SegmentConfiguration",
    "SegmentRevisionFeedbackRequestModel",
    "TranscriptLineResponseModel",
    "UsageLimits",
    "UserBodySegmentSaveRequest",
    "UserCodeSegmentSaveRequest",
    "UserHeadingSegmentSaveRequest",
    "ValidationError",
    "VideoToBlogType",
)



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="TranscriptLineResponseModel")


@attr.s(auto_attribs=True)
class TranscriptLineResponseModel:
    """Response model for a line in the transcript.

    Attributes:
        start_time (float):
        end_time (float):
        text (str):
    """

    start_time: float
    end_time: float
    text: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        start_time = self.start_time
        end_time = self.end_time
        text = self.text

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "start_time": start_time,
                "end_time": end_time,
                "text": text,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        start_time = d.pop("start_time")

        end_time = d.pop("end_time")

        text = d.pop("text")

        transcript_line_response_model = cls(
            start_time=start_time,
            end_time=end_time,
            text=text,
        )

        transcript_line_response_model.additional_properties = d
        return transcript_line_response_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.video_to_blog_type import VideoToBlogType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.document_generation_configuration import DocumentGenerationConfiguration


T = TypeVar("T", bound="JobCreateVideoToBlog")


@attr.s(auto_attribs=True)
class JobCreateVideoToBlog:
    """Video to blog job creation model.

    Attributes:
        type (VideoToBlogType): Input video types for the video to blog pipeline.
        status_update_webhook_url (Union[Unset, str]): This URL will be called with updated whenever the job updates.
            Default: ''.
        status_update_email (Union[Unset, str]): This address will sent an e-mail whenever the job updates. Defaults to
            the user creating the job. Default: ''.
        source_id (Union[Unset, str]): Source id for the media the job will process, e.g. youtube dQw4w9WgXcQ. Default:
            'youtube dQw4w9WgXcQ'.
        labels (Union[Unset, List[str]]): Arbitrary labels that may be passed through to job results.
        overrides (Union[Unset, DocumentGenerationConfiguration]): Class for configuring blog document generation.
    """

    type: VideoToBlogType
    status_update_webhook_url: Union[Unset, str] = ""
    status_update_email: Union[Unset, str] = ""
    source_id: Union[Unset, str] = "youtube dQw4w9WgXcQ"
    labels: Union[Unset, List[str]] = UNSET
    overrides: Union[Unset, "DocumentGenerationConfiguration"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        status_update_webhook_url = self.status_update_webhook_url
        status_update_email = self.status_update_email
        source_id = self.source_id
        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        overrides: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.overrides, Unset):
            overrides = self.overrides.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if status_update_webhook_url is not UNSET:
            field_dict["status_update_webhook_url"] = status_update_webhook_url
        if status_update_email is not UNSET:
            field_dict["status_update_email"] = status_update_email
        if source_id is not UNSET:
            field_dict["source_id"] = source_id
        if labels is not UNSET:
            field_dict["labels"] = labels
        if overrides is not UNSET:
            field_dict["overrides"] = overrides

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.document_generation_configuration import DocumentGenerationConfiguration

        d = src_dict.copy()
        type = VideoToBlogType(d.pop("type"))

        status_update_webhook_url = d.pop("status_update_webhook_url", UNSET)

        status_update_email = d.pop("status_update_email", UNSET)

        source_id = d.pop("source_id", UNSET)

        labels = cast(List[str], d.pop("labels", UNSET))

        _overrides = d.pop("overrides", UNSET)
        overrides: Union[Unset, DocumentGenerationConfiguration]
        if isinstance(_overrides, Unset):
            overrides = UNSET
        else:
            overrides = DocumentGenerationConfiguration.from_dict(_overrides)

        job_create_video_to_blog = cls(
            type=type,
            status_update_webhook_url=status_update_webhook_url,
            status_update_email=status_update_email,
            source_id=source_id,
            labels=labels,
            overrides=overrides,
        )

        job_create_video_to_blog.additional_properties = d
        return job_create_video_to_blog

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RegenerationLabel(str, Enum):
    DECLINE_TO_LABEL = "decline to label"
    DIDNT_MAKE_SENSE = "didn't make sense"
    INACCURATE = "inaccurate"
    INCOMPLETE = "incomplete"
    STYLE = "style"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.regeneration_label import RegenerationLabel
from ..types import UNSET, Unset

T = TypeVar("T", bound="SegmentRevisionFeedbackRequestModel")


@attr.s(auto_attribs=True)
class SegmentRevisionFeedbackRequestModel:
    """Response model for the body input of saving segment revisions after regeneration.

    Attributes:
        regeneration_reason (RegenerationLabel): Enumerable for labeling different reasons a segment was regenerated.
            The text values are also used by the frontend to display, retrieved via an endpoint
        regeneration_reason_options (Union[Unset, List[RegenerationLabel]]):
    """

    regeneration_reason: RegenerationLabel
    regeneration_reason_options: Union[Unset, List[RegenerationLabel]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        regeneration_reason = self.regeneration_reason.value

        regeneration_reason_options: Union[Unset, List[str]] = UNSET
        if not isinstance(self.regeneration_reason_options, Unset):
            regeneration_reason_options = []
            for regeneration_reason_options_item_data in self.regeneration_reason_options:
                regeneration_reason_options_item = regeneration_reason_options_item_data.value

                regeneration_reason_options.append(regeneration_reason_options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "regeneration_reason": regeneration_reason,
            }
        )
        if regeneration_reason_options is not UNSET:
            field_dict["regeneration_reason_options"] = regeneration_reason_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        regeneration_reason = RegenerationLabel(d.pop("regeneration_reason"))

        regeneration_reason_options = []
        _regeneration_reason_options = d.pop("regeneration_reason_options", UNSET)
        for regeneration_reason_options_item_data in _regeneration_reason_options or []:
            regeneration_reason_options_item = RegenerationLabel(regeneration_reason_options_item_data)

            regeneration_reason_options.append(regeneration_reason_options_item)

        segment_revision_feedback_request_model = cls(
            regeneration_reason=regeneration_reason,
            regeneration_reason_options=regeneration_reason_options,
        )

        segment_revision_feedback_request_model.additional_properties = d
        return segment_revision_feedback_request_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.blog_segment_type import BlogSegmentType
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserHeadingSegmentSaveRequest")


@attr.s(auto_attribs=True)
class UserHeadingSegmentSaveRequest:
    """Request model for a user added heading segment, type USER_HEADING.

    Attributes:
        id (str):
        text (str):
        segment_type (Union[Unset, BlogSegmentType]): Enumerable for the different types a BlogSegment can have.
            Default: BlogSegmentType.USER_HEADING.
    """

    id: str
    text: str
    segment_type: Union[Unset, BlogSegmentType] = BlogSegmentType.USER_HEADING
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        text = self.text
        segment_type: Union[Unset, str] = UNSET
        if not isinstance(self.segment_type, Unset):
            segment_type = self.segment_type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "text": text,
            }
        )
        if segment_type is not UNSET:
            field_dict["segment_type"] = segment_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        text = d.pop("text")

        _segment_type = d.pop("segment_type", UNSET)
        segment_type: Union[Unset, BlogSegmentType]
        if isinstance(_segment_type, Unset):
            segment_type = UNSET
        else:
            segment_type = BlogSegmentType(_segment_type)

        user_heading_segment_save_request = cls(
            id=id,
            text=text,
            segment_type=segment_type,
        )

        user_heading_segment_save_request.additional_properties = d
        return user_heading_segment_save_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.http_validation_error import HTTPValidationError
from ...models.job_create_video_to_blog import JobCreateVideoToBlog
from ...models.post_video_to_blog_job_api_v2_jobs_video_to_blog_post_response_post_video_to_blog_job_api_v2_jobs_video_to_blog_post import (
    PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
)
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: Client,
    json_body: JobCreateVideoToBlog,
    token: str,
) -> Dict[str, Any]:
    url = "{}/api/v2/jobs/video-to-blog".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["token"] = token

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = (
            PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost.from_dict(
                response.json()
            )
        )

        return response_200
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: JobCreateVideoToBlog,
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    r"""Create a video-to-blog job.

     Create a video-to-blog job.

    **Request body:**
    - `source_id` (`string`): media source ID formatted, e.g. `youtube dQw4w9WgXcQ` - the platform name,
    space,
        then the media ID on that platform
    - `status_update_email` (`string`): (optional) e-mail address to send an update to whenever the
    status of the job
        changes, defaults to the queueing user's email
    - `status_update_webhook_url` (`string`): (optional) a webhook to be called with a POST
        request whenever the status of the job changes
    - `type` (`string`): video-to-blog job type, can be `presentation` or `tutorial`
    - `overrides` (`dict`): (optional) overrides for the job type. Any overrides not specified will use
    the default.

    **Source ID types:**

    These are the supported `source_id` types - substitute the `$values` for your media:

    - `youtube $id` YouTube videos, $id for a YouTube video ID, e.g.
    https://www.youtube.com/watch?v=dQw4w9WgXcQ becomes `youtube dQw4w9WgXcQ`
    - `twitch $id` Twitch vods, $id for a Twitch vod ID, e.g. https://www.twitch.tv/videos/1079879708
    becomes `twitch 1079879708`
    - `facebook $channel $id` Facebook videos, $channel for a Facebook page ID and $id for a Facebook
    video ID on that page, e.g. https://www.facebook.com/PersonOfInterestTV/videos/1827475693951431
    becomes `facebook PersonOfInterestTV 1827475693951431`
    - `mux $id` Mux videos, $id for a Mux video ID, e.g.
    https://stream.mux.com/uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW.m3u8 becomes `mux
    uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW`
    - `url $url` Raw URL links, $url for a fully qualified URL that would download a media, e.g. `url
    https://download.blender.org/demo/movies/BBB/bbb_sunflower_1080p_60fps_normal.mp4`

    **Overrides:**

    *Please note that this is an experimental feature, and we can't currently provide support for it.*

    Overrides are set under three segment type keys: `body_segment`, `heading_segment`, and
    `question_segment`.
    The `body_segment` will define the generation parameters for the body of the blog post, the
    `heading_segment` will
    define the generation parameters for the heading of the blog post. The `question_segment` is
    currently unused.

    Each segment type has the following parameters:
    - `prompt_template_string` (`string`): (optional) a template string to use as the prompt for the
    generation. The
        transcript will be inserted into the template string at the `{TEXT}` placeholder. Takes
    precedence over
        `prompt_template_name`.
    - `prompt_template_name` (`string`): (optional) the filename of an internal template to use as the
    prompt for the
        generation. (These are for internal use only, and are not currently documented.)
    - `system_message_string` (`string`): (optional) a system message to use as the prompt for the
    generation. Takes
        precedence over `system_message_name`.
    - `system_message_name` (`string`): (optional) the filename of an internal system message to use as
    the prompt for
        the generation. (These are for internal use only, and are not currently documented.)
    - `completion_max_tokens` (`int`): (optional) the maximum number of tokens to generate for the
    segment.
    - `temperature` (`float`): (optional) the temperature to use for the generation.
    - `regeneration_fn` (`string`): (optional) the name of a function to use to regenerate the segment.
        (These are for internal use only, and are not currently documented.)
    - `regeneration_tries` (`int`): (optional) the number of times to try regenerating the segment if
    the generated
        text is below the `regeneration_threshold`.
    - `regeneration_threshold` (`float`): (optional) the threshold for the generated text to be above to
    be considered
        valid. If the generated text is below this threshold, the segment will be regenerated up to
    `regeneration_tries`

    For example, to override the `body_segment`, you would use the following in your request body:
    ```
    {
        ...
        \"overrides\": {
            \"body_segment\": {
               \"prompt_template_string\": \"Turn the following transcript into a blog post: {TEXT}\",
               \"system_message_string\": \"Make a great blog!\"
               \"completion_max_tokens\": 800,
               \"temperature\": 0.7,
               \"regeneration_tries\": 0,
               \"regeneration_threshold\": 1.0,
            }
        }
    }
    ```

    Args:
        token (str):
        json_body (JobCreateVideoToBlog): Video to blog job creation model.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        token=token,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: JobCreateVideoToBlog,
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    r"""Create a video-to-blog job.

     Create a video-to-blog job.

    **Request body:**
    - `source_id` (`string`): media source ID formatted, e.g. `youtube dQw4w9WgXcQ` - the platform name,
    space,
        then the media ID on that platform
    - `status_update_email` (`string`): (optional) e-mail address to send an update to whenever the
    status of the job
        changes, defaults to the queueing user's email
    - `status_update_webhook_url` (`string`): (optional) a webhook to be called with a POST
        request whenever the status of the job changes
    - `type` (`string`): video-to-blog job type, can be `presentation` or `tutorial`
    - `overrides` (`dict`): (optional) overrides for the job type. Any overrides not specified will use
    the default.

    **Source ID types:**

    These are the supported `source_id` types - substitute the `$values` for your media:

    - `youtube $id` YouTube videos, $id for a YouTube video ID, e.g.
    https://www.youtube.com/watch?v=dQw4w9WgXcQ becomes `youtube dQw4w9WgXcQ`
    - `twitch $id` Twitch vods, $id for a Twitch vod ID, e.g. https://www.twitch.tv/videos/1079879708
    becomes `twitch 1079879708`
    - `facebook $channel $id` Facebook videos, $channel for a Facebook page ID and $id for a Facebook
    video ID on that page, e.g. https://www.facebook.com/PersonOfInterestTV/videos/1827475693951431
    becomes `facebook PersonOfInterestTV 1827475693951431`
    - `mux $id` Mux videos, $id for a Mux video ID, e.g.
    https://stream.mux.com/uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW.m3u8 becomes `mux
    uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW`
    - `url $url` Raw URL links, $url for a fully qualified URL that would download a media, e.g. `url
    https://download.blender.org/demo/movies/BBB/bbb_sunflower_1080p_60fps_normal.mp4`

    **Overrides:**

    *Please note that this is an experimental feature, and we can't currently provide support for it.*

    Overrides are set under three segment type keys: `body_segment`, `heading_segment`, and
    `question_segment`.
    The `body_segment` will define the generation parameters for the body of the blog post, the
    `heading_segment` will
    define the generation parameters for the heading of the blog post. The `question_segment` is
    currently unused.

    Each segment type has the following parameters:
    - `prompt_template_string` (`string`): (optional) a template string to use as the prompt for the
    generation. The
        transcript will be inserted into the template string at the `{TEXT}` placeholder. Takes
    precedence over
        `prompt_template_name`.
    - `prompt_template_name` (`string`): (optional) the filename of an internal template to use as the
    prompt for the
        generation. (These are for internal use only, and are not currently documented.)
    - `system_message_string` (`string`): (optional) a system message to use as the prompt for the
    generation. Takes
        precedence over `system_message_name`.
    - `system_message_name` (`string`): (optional) the filename of an internal system message to use as
    the prompt for
        the generation. (These are for internal use only, and are not currently documented.)
    - `completion_max_tokens` (`int`): (optional) the maximum number of tokens to generate for the
    segment.
    - `temperature` (`float`): (optional) the temperature to use for the generation.
    - `regeneration_fn` (`string`): (optional) the name of a function to use to regenerate the segment.
        (These are for internal use only, and are not currently documented.)
    - `regeneration_tries` (`int`): (optional) the number of times to try regenerating the segment if
    the generated
        text is below the `regeneration_threshold`.
    - `regeneration_threshold` (`float`): (optional) the threshold for the generated text to be above to
    be considered
        valid. If the generated text is below this threshold, the segment will be regenerated up to
    `regeneration_tries`

    For example, to override the `body_segment`, you would use the following in your request body:
    ```
    {
        ...
        \"overrides\": {
            \"body_segment\": {
               \"prompt_template_string\": \"Turn the following transcript into a blog post: {TEXT}\",
               \"system_message_string\": \"Make a great blog!\"
               \"completion_max_tokens\": 800,
               \"temperature\": 0.7,
               \"regeneration_tries\": 0,
               \"regeneration_threshold\": 1.0,
            }
        }
    }
    ```

    Args:
        token (str):
        json_body (JobCreateVideoToBlog): Video to blog job creation model.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        token=token,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: JobCreateVideoToBlog,
    token: str,
) -> Response[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    r"""Create a video-to-blog job.

     Create a video-to-blog job.

    **Request body:**
    - `source_id` (`string`): media source ID formatted, e.g. `youtube dQw4w9WgXcQ` - the platform name,
    space,
        then the media ID on that platform
    - `status_update_email` (`string`): (optional) e-mail address to send an update to whenever the
    status of the job
        changes, defaults to the queueing user's email
    - `status_update_webhook_url` (`string`): (optional) a webhook to be called with a POST
        request whenever the status of the job changes
    - `type` (`string`): video-to-blog job type, can be `presentation` or `tutorial`
    - `overrides` (`dict`): (optional) overrides for the job type. Any overrides not specified will use
    the default.

    **Source ID types:**

    These are the supported `source_id` types - substitute the `$values` for your media:

    - `youtube $id` YouTube videos, $id for a YouTube video ID, e.g.
    https://www.youtube.com/watch?v=dQw4w9WgXcQ becomes `youtube dQw4w9WgXcQ`
    - `twitch $id` Twitch vods, $id for a Twitch vod ID, e.g. https://www.twitch.tv/videos/1079879708
    becomes `twitch 1079879708`
    - `facebook $channel $id` Facebook videos, $channel for a Facebook page ID and $id for a Facebook
    video ID on that page, e.g. https://www.facebook.com/PersonOfInterestTV/videos/1827475693951431
    becomes `facebook PersonOfInterestTV 1827475693951431`
    - `mux $id` Mux videos, $id for a Mux video ID, e.g.
    https://stream.mux.com/uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW.m3u8 becomes `mux
    uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW`
    - `url $url` Raw URL links, $url for a fully qualified URL that would download a media, e.g. `url
    https://download.blender.org/demo/movies/BBB/bbb_sunflower_1080p_60fps_normal.mp4`

    **Overrides:**

    *Please note that this is an experimental feature, and we can't currently provide support for it.*

    Overrides are set under three segment type keys: `body_segment`, `heading_segment`, and
    `question_segment`.
    The `body_segment` will define the generation parameters for the body of the blog post, the
    `heading_segment` will
    define the generation parameters for the heading of the blog post. The `question_segment` is
    currently unused.

    Each segment type has the following parameters:
    - `prompt_template_string` (`string`): (optional) a template string to use as the prompt for the
    generation. The
        transcript will be inserted into the template string at the `{TEXT}` placeholder. Takes
    precedence over
        `prompt_template_name`.
    - `prompt_template_name` (`string`): (optional) the filename of an internal template to use as the
    prompt for the
        generation. (These are for internal use only, and are not currently documented.)
    - `system_message_string` (`string`): (optional) a system message to use as the prompt for the
    generation. Takes
        precedence over `system_message_name`.
    - `system_message_name` (`string`): (optional) the filename of an internal system message to use as
    the prompt for
        the generation. (These are for internal use only, and are not currently documented.)
    - `completion_max_tokens` (`int`): (optional) the maximum number of tokens to generate for the
    segment.
    - `temperature` (`float`): (optional) the temperature to use for the generation.
    - `regeneration_fn` (`string`): (optional) the name of a function to use to regenerate the segment.
        (These are for internal use only, and are not currently documented.)
    - `regeneration_tries` (`int`): (optional) the number of times to try regenerating the segment if
    the generated
        text is below the `regeneration_threshold`.
    - `regeneration_threshold` (`float`): (optional) the threshold for the generated text to be above to
    be considered
        valid. If the generated text is below this threshold, the segment will be regenerated up to
    `regeneration_tries`

    For example, to override the `body_segment`, you would use the following in your request body:
    ```
    {
        ...
        \"overrides\": {
            \"body_segment\": {
               \"prompt_template_string\": \"Turn the following transcript into a blog post: {TEXT}\",
               \"system_message_string\": \"Make a great blog!\"
               \"completion_max_tokens\": 800,
               \"temperature\": 0.7,
               \"regeneration_tries\": 0,
               \"regeneration_threshold\": 1.0,
            }
        }
    }
    ```

    Args:
        token (str):
        json_body (JobCreateVideoToBlog): Video to blog job creation model.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        token=token,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: JobCreateVideoToBlog,
    token: str,
) -> Optional[
    Union[
        HTTPValidationError,
        PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost,
    ]
]:
    r"""Create a video-to-blog job.

     Create a video-to-blog job.

    **Request body:**
    - `source_id` (`string`): media source ID formatted, e.g. `youtube dQw4w9WgXcQ` - the platform name,
    space,
        then the media ID on that platform
    - `status_update_email` (`string`): (optional) e-mail address to send an update to whenever the
    status of the job
        changes, defaults to the queueing user's email
    - `status_update_webhook_url` (`string`): (optional) a webhook to be called with a POST
        request whenever the status of the job changes
    - `type` (`string`): video-to-blog job type, can be `presentation` or `tutorial`
    - `overrides` (`dict`): (optional) overrides for the job type. Any overrides not specified will use
    the default.

    **Source ID types:**

    These are the supported `source_id` types - substitute the `$values` for your media:

    - `youtube $id` YouTube videos, $id for a YouTube video ID, e.g.
    https://www.youtube.com/watch?v=dQw4w9WgXcQ becomes `youtube dQw4w9WgXcQ`
    - `twitch $id` Twitch vods, $id for a Twitch vod ID, e.g. https://www.twitch.tv/videos/1079879708
    becomes `twitch 1079879708`
    - `facebook $channel $id` Facebook videos, $channel for a Facebook page ID and $id for a Facebook
    video ID on that page, e.g. https://www.facebook.com/PersonOfInterestTV/videos/1827475693951431
    becomes `facebook PersonOfInterestTV 1827475693951431`
    - `mux $id` Mux videos, $id for a Mux video ID, e.g.
    https://stream.mux.com/uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW.m3u8 becomes `mux
    uNbxnGLKJ00yfbijDO8COxTOyVKT01xpxW`
    - `url $url` Raw URL links, $url for a fully qualified URL that would download a media, e.g. `url
    https://download.blender.org/demo/movies/BBB/bbb_sunflower_1080p_60fps_normal.mp4`

    **Overrides:**

    *Please note that this is an experimental feature, and we can't currently provide support for it.*

    Overrides are set under three segment type keys: `body_segment`, `heading_segment`, and
    `question_segment`.
    The `body_segment` will define the generation parameters for the body of the blog post, the
    `heading_segment` will
    define the generation parameters for the heading of the blog post. The `question_segment` is
    currently unused.

    Each segment type has the following parameters:
    - `prompt_template_string` (`string`): (optional) a template string to use as the prompt for the
    generation. The
        transcript will be inserted into the template string at the `{TEXT}` placeholder. Takes
    precedence over
        `prompt_template_name`.
    - `prompt_template_name` (`string`): (optional) the filename of an internal template to use as the
    prompt for the
        generation. (These are for internal use only, and are not currently documented.)
    - `system_message_string` (`string`): (optional) a system message to use as the prompt for the
    generation. Takes
        precedence over `system_message_name`.
    - `system_message_name` (`string`): (optional) the filename of an internal system message to use as
    the prompt for
        the generation. (These are for internal use only, and are not currently documented.)
    - `completion_max_tokens` (`int`): (optional) the maximum number of tokens to generate for the
    segment.
    - `temperature` (`float`): (optional) the temperature to use for the generation.
    - `regeneration_fn` (`string`): (optional) the name of a function to use to regenerate the segment.
        (These are for internal use only, and are not currently documented.)
    - `regeneration_tries` (`int`): (optional) the number of times to try regenerating the segment if
    the generated
        text is below the `regeneration_threshold`.
    - `regeneration_threshold` (`float`): (optional) the threshold for the generated text to be above to
    be considered
        valid. If the generated text is below this threshold, the segment will be regenerated up to
    `regeneration_tries`

    For example, to override the `body_segment`, you would use the following in your request body:
    ```
    {
        ...
        \"overrides\": {
            \"body_segment\": {
               \"prompt_template_string\": \"Turn the following transcript into a blog post: {TEXT}\",
               \"system_message_string\": \"Make a great blog!\"
               \"completion_max_tokens\": 800,
               \"temperature\": 0.7,
               \"regeneration_tries\": 0,
               \"regeneration_threshold\": 1.0,
            }
        }
    }
    ```

    Args:
        token (str):
        json_body (JobCreateVideoToBlog): Video to blog job creation model.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PostVideoToBlogJobApiV2JobsVideoToBlogPostResponsePostVideoToBlogJobApiV2JobsVideoToBlogPost]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            token=token,
        )
    ).parsed



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['contenda_api_client',
 'contenda_api_client.api',
 'contenda_api_client.api.content_and_results',
 'contenda_api_client.api.experimental',
 'contenda_api_client.api.identity',
 'contenda_api_client.api.jobs',
 'contenda_api_client.api.media',
 'contenda_api_client.api.utility',
 'contenda_api_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.3.0', 'httpx>=0.15.4,<0.25.0', 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'contenda-api-client',
    'version': '0.1.1',
    'description': 'A client library for accessing Contenda API',
    'long_description': '# contenda-api-client\nA client library for accessing Contenda API\n\n## Usage\nFirst, create a client:\n\n```python\nfrom contenda_api_client import AuthenticatedClient\n\nclient = AuthenticatedClient(base_url="https://prod.contenda.io", token="SuperSecretToken")\n```\n\nNote: You\'ll need to exchange a token for your API key first through the identity endpoint. \n\nNow call your endpoint and use your models:\n\n```python\nfrom contenda_api_client.models import MyDataModel\nfrom contenda_api_client.api.my_tag import get_my_data_model\nfrom contenda_api_client.types import Response\n\nmy_data: MyDataModel = get_my_data_model.sync(client=client)\n# or if you need more info (e.g. status_code)\nresponse: Response[MyDataModel] = get_my_data_model.sync_detailed(client=client)\n```\n\nOr do the same thing with an async version:\n\n```python\nfrom contenda_api_client.models import MyDataModel\nfrom contenda_api_client.api.my_tag import get_my_data_model\nfrom contenda_api_client.types import Response\n\nmy_data: MyDataModel = await get_my_data_model.asyncio(client=client)\nresponse: Response[MyDataModel] = await get_my_data_model.asyncio_detailed(client=client)\n```\n\nThere are more settings on the generated `Client` class which let you control more runtime behavior, check out the docstring on that class for more info.\n\nThings to know:\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `contenda_api_client.api.default`\n\n',
    'author': 'Lilly Chen',
    'author_email': 'lilly@contenda.co',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="GenerateAccessToken")


@attr.s(auto_attribs=True)
class GenerateAccessToken:
    """Generate access token model.

    Attributes:
        email (Union[Unset, str]): The e-mail address of the user. Default: ''.
        api_key (Union[Unset, str]): The API key of the user. Default: ''.
    """

    email: Union[Unset, str] = ""
    api_key: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        api_key = self.api_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if email is not UNSET:
            field_dict["email"] = email
        if api_key is not UNSET:
            field_dict["api_key"] = api_key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email", UNSET)

        api_key = d.pop("api_key", UNSET)

        generate_access_token = cls(
            email=email,
            api_key=api_key,
        )

        generate_access_token.additional_properties = d
        return generate_access_token

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
